#!/bin/bash
#TripMode Diagnostic Tool
#Ver. 2021.02.03

tput clear
echo "########################"
echo "TripMode Diagnostic Tool"
echo "########################"
echo ""
echo "This tool will generate a zip file on your Desktop that contains information destined for TripMode issues troubleshooting."
echo "It will include information such as a full system report, the TripMode application support files, and TripMode preferences."
echo "The report may contain private information such as your Wi-Fi name, user folder path, etc."
echo "Only the information needed to troubleshoot the issue is used. It will never be shared with a 3rd party."
echo "Please quit TripMode before proceeding."
echo ""
echo ""
read -n 1 -p "Press any key to continue..."
tput clear
echo "Please wait while the TripMode diagnostic is being generated. This can take a minute."
echo ""

# Init
tripmodeDiagDir="TripModeDiag-$(date +%Y-%m-%d_%H.%M.%S)"
tripmodeDiagPath=~/Desktop/${tripmodeDiagDir}
userDir=~
mkdir ${tripmodeDiagPath}
mkdir ${tripmodeDiagPath}/Logs
mkdir ${tripmodeDiagPath}/Prefs
mkdir ${tripmodeDiagPath}/Caches

# Copy TripMode 2 application preferences
cp ~/Library/Preferences/ch.tripmode.TripMode.plist "${tripmodeDiagPath}/Prefs"


# Copy any TripMode crash logs
cp /Library/Logs/DiagnosticReports/*TripMode* ${tripmodeDiagPath}/Logs
tput clear
cp ~/Library/Logs/DiagnosticReports/*TripMode* ${tripmodeDiagPath}/Logs
tput clear

# Copy TripMode database
# TM2 and earlier
cp -a "${userDir}/Library/Application Support/TripMode/." ${tripmodeDiagPath}/

# TM3 and later
cp -a "${userDir}/Library/Containers/ch.tripmode.TripMode-setapp/Data/Library/Application Support/TripMode/." "${tripmodeDiagPath}/App Support"
cp -a "${userDir}/Library/Containers/ch.tripmode.TripMode/Data/Library/Application Support/TripMode/." "${tripmodeDiagPath}/App Support"
cp -a "${userDir}/Library/Containers/com.alix-sarl.TripMode/Data/Library/Application Support/TripMode/." "${tripmodeDiagPath}/App Support"
cp -a "${userDir}/Library/Containers/ch.tripmode.TripMode-setapp/Data/Library/Caches/ch.tripmode.TripMode/." "${tripmodeDiagPath}/Caches"
cp -a "${userDir}/Library/Containers/ch.tripmode.TripMode/Data/Library/Caches/ch.tripmode.TripMode/." "${tripmodeDiagPath}/Caches"
cp -a "${userDir}/Library/Containers/com.alix-sarl.TripMode/Data/Library/Caches/ch.tripmode.TripMode/." "${tripmodeDiagPath}/Caches"
cp -a "${userDir}/Library/Containers/ch.tripmode.TripMode-setapp/Data/Library/Preferences/ch.tripmode.TripMode-setapp.plist" "${tripmodeDiagPath}/Prefs"
cp -a "${userDir}/Library/Containers/ch.tripmode.TripMode/Data/Library/Preferences/ch.tripmode.TripMode.plist" "${tripmodeDiagPath}/Prefs"
cp -a "${userDir}/Library/Containers/com.alix-sarl.TripMode/Data/Library/Preferences/ch.tripmode.TripMode-setapp.plist" "${tripmodeDiagPath}/Prefs"

# Generate System Report
system_profiler -detailLevel full -xml > ${tripmodeDiagPath}/Report-$(hostname -s).spx

# Zip everything
cd ${userDir}/Desktop/
zip -r -X "${tripmodeDiagDir}.zip" "${tripmodeDiagDir}"

# Clean up
rm -R "${tripmodeDiagDir}"

tput clear
echo "Done!"
echo "The diagnostic has been saved in ${tripmodeDiagDir}.zip on your desktop. Please send it to the TripMode support Team via https://www.tripmode.ch/support"
echo ""
read -n 1 -p "Press any key to quit..."
exit 0;
